Coverage for expo_notifications/managers/device_manager.py: 73%

1 from django.db import models

2

3

4 class DeviceQueryset(models.QuerySet):

5 @property

6 def active(self) -> "DeviceQueryset":

7 return self.filter(is_active=True)

8

9

10 class DeviceManager(models.Manager):

11 def get_queryset(self) -> "DeviceQueryset":

12 return DeviceQueryset(self.model, using=self._db)

13

14 @property

15 def active(self) -> "DeviceQueryset":

16 return self.get_queryset().active